@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2020 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2021 LibRaw LLC (info@libraw.org)
  *
  LibRaw is free software; you can redistribute it and/or modify
  it under the terms of the one of two licenses as you choose:
@@ -34,16 +34,23 @@ static const char *static_camera_list[] = {
 	"Apple iPhone 8",
 	"Apple iPhone 8 plus",
 	"Apple iPhone X",
+	"Apple iPhone 12 Pro",
+	"Apple iPhone 12 Pro Max",
+	"Apple iPhone 13 Pro",
 	"Apple QuickTake 100",
 	"Apple QuickTake 150",
 	"Apple QuickTake 200",
+#ifdef LIBRAW_OLD_VIDEO_SUPPORT
 	"ARRI ALEXA",
 	"ARRI ALEXA65",
 	"ARRI ALEXA LF",
 	"ARRI ALEXA XT",
 	"ARRI ALEXA SXT",
+#endif
 	"ASUS ZenPhone4",
 	"ASUS ZenPhone6",
+	"AutelRobotics XB015",
+	"AutelRobotics XT705 (EVO II)",
 	"AVT F-080C",
 	"AVT F-145C",
 	"AVT F-201C",
@@ -71,19 +78,19 @@ static const char *static_camera_list[] = {
 	"Canon PowerShot A540 (CHDK hack)",
 	"Canon PowerShot A550 (CHDK hack)",
 	"Canon PowerShot A560 (CHDK hack)",
-	"Canon PowerShot A570 (CHDK hack)",
-	"Canon PowerShot A590 (CHDK hack)",
+	"Canon PowerShot A570 IS (CHDK hack)",
+	"Canon PowerShot A590 IS (CHDK hack)",
 	"Canon PowerShot A610 (CHDK hack)",
 	"Canon PowerShot A620 (CHDK hack)",
 	"Canon PowerShot A630 (CHDK hack)",
 	"Canon PowerShot A640 (CHDK hack)",
-	"Canon PowerShot A650 (CHDK hack)",
+	"Canon PowerShot A650 IS (CHDK hack)",
 	"Canon PowerShot A710 IS (CHDK hack)",
 	"Canon PowerShot A720 IS (CHDK hack)",
 	"Canon PowerShot A3300 IS (CHDK hack)",
 	"Canon PowerShot D10 (CHDK hack)",
-	"Canon PowerShot ELPH 130 IS (CHDK hack)",
-	"Canon PowerShot ELPH 160 IS (CHDK hack)",
+	"Canon PowerShot ELPH 130 IS / IXUS 140 / IXY 110F (CHDK hack)",
+	"Canon PowerShot ELPH 160 / IXUS 160 (CHDK hack)",
 	"Canon PowerShot Pro70",
 	"Canon PowerShot Pro90 IS",
 	"Canon PowerShot Pro1",
@@ -113,9 +120,11 @@ static const char *static_camera_list[] = {
 	"Canon PowerShot S2 IS (CHDK hack)",
 	"Canon PowerShot S3 IS (CHDK hack)",
 	"Canon PowerShot S5 IS (CHDK hack)",
-	"Canon PowerShot SD300 (CHDK hack)",
-	"Canon PowerShot SD750 (CHDK hack)",
-	"Canon PowerShot SD950 (CHDK hack)",
+	"Canon PowerShot SD300 / IXUS 40 / IXY Digital 50 (CHDK hack)",
+	"Canon PowerShot SD750 / IXUS 75 / IXY Digital 90 (CHDK hack)",
+	"Canon PowerShot SD900 / Digital IXUS 900 Ti / IXY Digital 1000 (CHDK hack)",
+	"Canon PowerShot SD950 IS / Digital IXUS 960 IS / IXY Digital 2000 IS (CHDK hack)",
+	"Canon PowerShot SD1200 IS / Digital IXUS 95 IS / IXY Digital 110 IS (CHDK hack)",
 	"Canon PowerShot S30",
 	"Canon PowerShot S40",
 	"Canon PowerShot S45",
@@ -128,6 +137,7 @@ static const char *static_camera_list[] = {
 	"Canon PowerShot S110",
 	"Canon PowerShot S120",
 	"Canon PowerShot SX1 IS",
+	"Canon PowerShot SX40 HS (CHDK hack, CR2)",
 	"Canon PowerShot SX50 HS",
 	"Canon PowerShot SX60 HS",
 	"Canon PowerShot SX70 HS",
@@ -138,14 +148,17 @@ static const char *static_camera_list[] = {
 	"Canon PowerShot SX160 IS (CHDK hack)",
 	"Canon PowerShot SX220 HS (CHDK hack)",
 	"Canon PowerShot SX510 HS (CHDK hack)",
+	"Canon PowerShot SX710 HS (CHDK hack)",
 	"Canon PowerShot SX10 IS (CHDK hack)",
 	"Canon PowerShot SX20 IS (CHDK hack)",
 	"Canon PowerShot SX30 IS (CHDK hack)",
-	"Canon PowerShot IXUS 95 (CHDK hack)",
-	"Canon PowerShot IXUS 160 (CHDK hack)",
-	"Canon PowerShot IXUS 900Ti (CHDK hack)",
 	"Canon EOS R",
 	"Canon EOS RP",
+	"Canon EOS R3",
+	"Canon EOS R5",
+	"Canon EOS R6",
+	"Canon EOS R7",
+	"Canon EOS R10",
 	"Canon EOS D30",
 	"Canon EOS D60",
 	"Canon EOS 5DS",
@@ -185,13 +198,16 @@ static const char *static_camera_list[] = {
 	"Canon EOS 750D / Rebel T6i / Kiss X8i",
 	"Canon EOS 760D / Rebel T6S / 8000D",
 	"Canon EOS 800D / Rebel T7i / Kiss X9i",
+	"Canon EOS 850D / Rebel T8i / Kiss X10i",
 	"Canon EOS 1000D / Digital Rebel XS / Kiss F",
 	"Canon EOS 1100D / Rebel T3 / Kiss X50",
 	"Canon EOS 1200D / Kiss X70 / REBEL T5 / Hi",
 	"Canon EOS 1300D / Rebel T6 / Kiss X80",
 	"Canon EOS 1500D / 2000D / Rebel T7 / Kiss X90",
 	"Canon EOS 3000D / 4000D / Rebel T100",
+#ifdef LIBRAW_OLD_VIDEO_SUPPORT
 	"Canon EOS C500",
+#endif
 	"Canon EOS D2000",
 	"Canon EOS M",
 	"Canon EOS M2",
@@ -201,18 +217,19 @@ static const char *static_camera_list[] = {
 	"Canon EOS M6 Mark II",
 	"Canon EOS M10",
 	"Canon EOS M50 / Kiss M",
+	"Canon EOS M50 Mark II",
 	"Canon EOS M100",
 	"Canon EOS M200",
 	"Canon EOS-1D C",
 	"Canon EOS-1D X",
 	"Canon EOS-1D X Mark II",
-	"Canon EOS-1D X Mark III (lossless compressed only)",
+	"Canon EOS-1D X Mark III",
 	"Canon EOS-1D",
 	"Canon EOS-1D Mark II",
 	"Canon EOS-1D Mark II N",
 	"Canon EOS-1D Mark III",
 	"Canon EOS-1D Mark IV",
-	"Canon EOS-1DS",
+	"Canon EOS-1Ds",
 	"Canon EOS-1Ds Mark II",
 	"Canon EOS-1Ds Mark III",
 	"Casio QV-2000UX (secret menu hack)",
@@ -276,7 +293,11 @@ static const char *static_camera_list[] = {
 	"DJI 4384x3288",
 	"DJI Mavic Air",
 	"DJI Mavic Air2",
+	"DJI Mavic Air 2S",
+	"DJI Mavic Mini2",
+	"DJI Mavic 3",
 	"DJI Osmo Action",
+	"DJI Pocket",
 	"DJI Phantom4 Pro/Pro+",
 	"DJI Zenmuse X5",
 	"DJI Zenmuse X5R",
@@ -318,8 +339,10 @@ static const char *static_camera_list[] = {
 	"FujiFilm HS30EXR / HS33EXR / HS35EXR",
 	"FujiFilm HS50EXR",
 	"FujiFilm GFX 50S",
+	"FujiFilm GFX 50S II",
 	"FujiFilm GFX 50R",
 	"FujiFilm GFX 100",
+	"FujiFilm GFX 100S",
 	"FujiFilm X-Pro1",
 	"FujiFilm X-Pro2",
 	"FujiFilm X-Pro3",
@@ -327,7 +350,7 @@ static const char *static_camera_list[] = {
 	"FujiFilm XQ1",
 	"FujiFilm XQ2",
 	"FujiFilm X100",
-	"FujiFilm X100f",
+	"FujiFilm X100F",
 	"FujiFilm X100S",
 	"FujiFilm X100T",
 	"FujiFilm X100V",
@@ -346,18 +369,22 @@ static const char *static_camera_list[] = {
 	"FujiFilm X-E2",
 	"FujiFilm X-E2S",
 	"FujiFilm X-E3",
+	"FujiFilm X-E4",
 	"FujiFilm X-M1",
 	"FujiFilm XF1",
 	"FujiFilm XF10",
 	"FujiFilm X-H1",
+	"FujiFilm X-H2S",
 	"FujiFilm X-T1",
+	"FujiFilm X-S10",
 	"FujiFilm X-T1 Graphite Silver",
 	"FujiFilm X-T2",
 	"FujiFilm X-T3",
-	"FujiFilm X-T4 (uncompressed and lossless compressed only)",
+	"FujiFilm X-T4",
 	"FujiFilm X-T10",
 	"FujiFilm X-T20",
 	"FujiFilm X-T30",
+	"FujiFilm X-T30 II",
 	"FujiFilm X-T100",
 	"FujiFilm X-T200",
 	"FujiFilm IS-1",
@@ -369,12 +396,16 @@ static const char *static_camera_list[] = {
 	"Google Pixel XL",
 	"Google Pixel 3a",
 	"Google Pixel 4 XL",
+	"Google Pixel 4a (5G)",
+	"Google Pixel 5",
 #ifdef  USE_GPRSDK
 	"GoPro Fusion",
 	"GoPro HERO5",
 	"GoPro HERO6",
 	"GoPro HERO7",
 	"GoPro HERO8",
+	"GoPro HERO9",
+	"GoPro HERO10",
 #endif
 	"Hasselblad H2D-22",
 	"Hasselblad H2D-39",
@@ -397,6 +428,7 @@ static const char *static_camera_list[] = {
 	"Hasselblad A6D-100c", // Aerial camera
 	"Hasselblad CFV",
 	"Hasselblad CFV-50",
+	"Hasselblad CFV II 50C",
 	"Hasselblad CFH",
 	"Hasselblad CF-22",
 	"Hasselblad CF-31",
@@ -423,6 +455,7 @@ static const char *static_camera_list[] = {
 	"Huawei P10+ (VKY-L09)",
 	"Huawei P10 Lite (WAS-LX1A)",
 	"Huawei P20 (EML-L09)",
+	"Huawei P20 Lite (ANE-LX1)",
 	"Huawei P20 Pro (CLT-L29/L09)",
 	"Huawei P30 Pro (VOG-L29)",
 	"Huawei Honor6a",
@@ -433,9 +466,11 @@ static const char *static_camera_list[] = {
 	"Huawei Honor20",
 	"Huawei Honor View 10 (BKL-L09)",
 	"Huawei Honor View 20 (PCT-L29)",
+	"Huawei Honor 20 Pro (YAL-L41)",
 	"Huawei Mate8 (NXT-L29)",
 	"Huawei Mate10 (BLA-L29)",
 	"Huawei Mate20 Pro (LYA-L29)",
+	"Huawei Mate20 Lite (SNE-LX1)",
 	"Imacon Ixpress 96, 96C",
 	"Imacon Ixpress 384, 384C (single shot only)",
 	"Imacon Ixpress 132C",
@@ -443,6 +478,7 @@ static const char *static_camera_list[] = {
 	"ISG 2020x1520",
 	"Ikonoskop A-Cam dII Panchromatic",
 	"Ikonoskop A-Cam dII",
+	"Kandao QooCam 8K",
 	"Kinefinity KineMINI",
 	"Kinefinity KineRAW Mini",
 	"Kinefinity KineRAW S35",
@@ -457,7 +493,6 @@ static const char *static_camera_list[] = {
 	"Kodak DCS420",
 	"Kodak DCS460",
 	"Kodak DCS460M",
-	"Kodak DCS460",
 	"Kodak DCS520C",
 	"Kodak DCS560C",
 	"Kodak DCS620C",
@@ -519,7 +554,7 @@ static const char *static_camera_list[] = {
 	"Leaf Credo 40",
 	"Leaf Credo 50",
 	"Leaf Credo 60",
-	"Leaf Credo 80 (low compression mode only)",
+	"Leaf Credo 80",
 	"Leaf DCB-II",
 	"Leaf Valeo 6",
 	"Leaf Valeo 11",
@@ -548,7 +583,9 @@ static const char *static_camera_list[] = {
 	"Leica M10",
 	"Leica M10-D",
 	"Leica M10-P",
+	"Leica M10-R",
 	"Leica M10 Monochrom",
+	"Leica M11",
 	"Leica M (Typ 240)",
 	"Leica M (Typ 262)",
 	"Leica Monochrom (Typ 240)",
@@ -560,11 +597,14 @@ static const char *static_camera_list[] = {
 	"Leica Q (Typ 116)",
 	"Leica Q-P",
 	"Leica Q2",
+	"Leica Q2 Monochrom",
 	"Leica S",
 	"Leica S2",
+	"Leica S3",
 	"Leica S (Typ 007)",
 	"Leica SL (Typ 601)",
 	"Leica SL2",
+	"Leica SL2-S",
 	"Leica T (Typ 701)",
 	"Leica TL",
 	"Leica TL2",
@@ -582,8 +622,10 @@ static const char *static_camera_list[] = {
 	"Leica X VARIO (Typ 107)",
 	"LG G3",
 	"LG G4",
+	"LG G5 (H850)",
 	"LG G6",
 	"LG V20 (F800K)",
+	"LG V20 (H910)",
 	"LG VS995",
 	"Logitech Fotoman Pixtura",
 	"Mamiya ZD",
@@ -624,7 +666,7 @@ static const char *static_camera_list[] = {
 	"Nikon D40X",
 	"Nikon D5",
 	"Nikon D50",
-	"Nikon D5",
+	"Nikon D6",
 	"Nikon D60",
 	"Nikon D70",
 	"Nikon D70s",
@@ -662,9 +704,14 @@ static const char *static_camera_list[] = {
 	"Nikon D7200",
 	"Nikon D7500",
 	"Nikon Df",
+	"Nikon Z 5",
 	"Nikon Z 6",
+	"Nikon Z 6 II",
 	"Nikon Z 7",
+	"Nikon Z 7 II",
+	"Nikon Z 9 (HE/HE* formats are not supported yet)",
 	"Nikon Z 50",
+	"Nikon Z fc",
 	"Nikon 1 AW1",
 	"Nikon 1 J1",
 	"Nikon 1 J2",
@@ -710,6 +757,8 @@ static const char *static_camera_list[] = {
 	"Nikon Coolpix S6 (\"DIAG RAW\" hack)",
 	"Nikon Coolscan NEF",
 	"Nokia 7 Plus",
+	"Nokia 8.3 5G",
+	"Nokia 9",
 	"Nokia N95",
 	"Nokia X2",
 	"Nokia 1200x1600",
@@ -748,6 +797,7 @@ static const char *static_camera_list[] = {
 	"Olympus E-P2",
 	"Olympus E-P3",
 	"Olympus E-P5",
+	"Olympus E-P7",
 	"Olympus E-PL1",
 	"Olympus E-PL1s",
 	"Olympus E-PL2",
@@ -767,6 +817,7 @@ static const char *static_camera_list[] = {
 	"Olympus E-M10",
 	"Olympus E-M10 Mark II",
 	"Olympus E-M10 Mark III",
+	"Olympus E-M10 Mark IV",
 	"Olympus E-M5",
 	"Olympus E-M5 Mark II",
 	"Olympus E-M5 Mark III",
@@ -790,12 +841,16 @@ static const char *static_camera_list[] = {
 	"Olympus XZ-1",
 	"Olympus XZ-2",
 	"Olympus XZ-10",
+	"OM Digital Solutions OM-1",
 	"OmniVision 4688",
 	"OmniVision OV5647",
 	"OmniVision OV5648",
 	"OmniVision OV8850",
 	"OmniVision 13860",
+	"OnePlus 6 (A6003)",
 	"OnePlus 6T",
+	"OnePlus 7 Pro (GM1913)",
+	"OnePlus 8 Pro (IN2023)",
 	"OnePlus One",
 	"OnePlus A3303",
 	"OnePlus A5000",
@@ -827,6 +882,7 @@ static const char *static_camera_list[] = {
 	"Panasonic DMC-G8 / G80 / G81 / G85",
 	"Panasonic DC-G9",
 	"Panasonic DC-G90 / G95 / G91 / G99",
+	"Panasonic DC-G100 / G110",
 	"Panasonic DMC-GF1",
 	"Panasonic DMC-GF2",
 	"Panasonic DMC-GF3",
@@ -841,6 +897,7 @@ static const char *static_camera_list[] = {
 	"Panasonic AG-GH4",
 	"Panasonic DC-GH5",
 	"Panasonic DC-GH5S",
+	"Panasonic DC-GH5 Mark II",
 	"Panasonic DMC-GM1",
 	"Panasonic DMC-GM1s",
 	"Panasonic DMC-GM5",
@@ -865,6 +922,7 @@ static const char *static_camera_list[] = {
 	"Panasonic DC-S1",
 	"Panasonic DC-S1H",
 	"Panasonic DC-S1R",
+	"Panasonic DC-S5",
 	"Panasonic DMC-ZS40, DMC-TZ60 / TZ61",
 	"Panasonic DMC-ZS50, DMC-TZ70 / TZ71",
 	"Panasonic DMC-ZS60, DMC-TZ80 / TZ81 / TZ82 / TZ85",
@@ -894,7 +952,8 @@ static const char *static_camera_list[] = {
 	"Pentax K-1",
 	"Pentax K-1 Mark II",
 	"Pentax K-3",
-	"Pentax K-3 II",
+	"Pentax K-3 Mark II",
+	"Pentax K-3 Mark III",
 	"Pentax K-30",
 	"Pentax K-5",
 	"Pentax K-5 II",
@@ -955,10 +1014,14 @@ static const char *static_camera_list[] = {
 #endif
 	"RaspberryPi Camera",
 	"RaspberryPi Camera V2",
+#ifdef USE_6BY9RPI
+	"RaspberryPi HQ Camera",
+#endif
 	"Ricoh GR",
 	"Realme 3 Pro",
 	"Ricoh GR II",
 	"Ricoh GR III",
+	"Ricoh GR IIIx",
 	"Ricoh GR Digital",
 	"Ricoh GR Digital II",
 	"Ricoh GR Digital III",
@@ -971,8 +1034,10 @@ static const char *static_camera_list[] = {
 	"Ricoh GXR Ricoh Lens A16 24-85mm F3.5-5.5",
 	"Ricoh GXR Ricoh Lens S10 24-72mm F2.5-4.4 VC",
 	"Ricoh GXR Ricoh Lens P10 28-300 mm F3.5-5.6 VC",
+#ifdef LIBRAW_OLD_VIDEO_SUPPORT
 #ifndef NO_JASPER
 	"Redcode R3D format",
+#endif
 #endif
 	"Rollei d530flex",
 	"RoverShot 3320af",
@@ -1066,15 +1131,21 @@ static const char *static_camera_list[] = {
 	"SMaL Ultra-Pocket 3",
 	"SMaL Ultra-Pocket 4",
 	"SMaL Ultra-Pocket 5",
+	"Sony ILCE-1 (A1)",
 	"Sony ILCE-7 (A7)",
 	"Sony ILCE-7M2 (A7 II)",
 	"Sony ILCE-7M3 (A7 III)",
-	"Sony ILCE-7R (A7R",
+	"Sony ILCE-7M4 (A7 IV)",
+	"Sony ILCE-7C (A7C)",
+	"Sony ILCE-7R (A7R)",
 	"Sony ILCE-7RM2 (A7R II)",
 	"Sony ILCE-7RM3 (A7R III)",
+	"Sony ILCE-7RM3A (A7R IIIA)",
 	"Sony ILCE-7RM4 (A7R IV)",
+	"Sony ILCE-7RM4A (A7R IVA)",
 	"Sony ILCE-7S (A7S)",
-	"Sony ILCE-7S2 (A7S II)",
+	"Sony ILCE-7SM2 (A7S II)",
+	"Sony ILCE-7SM3 (A7S III)",
 	"Sony ILCE-9 (A9)",
 	"Sony ILCE-9M2 (A9 II)",
 	"Sony ILCA-68 (A68)",
@@ -1159,22 +1230,32 @@ static const char *static_camera_list[] = {
 	"Sony IMX230",
 	"Sony IMX298-mipi 16mp",
 	"Sony IMX219-mipi 8mp",
+	"Sony Xperia 5 II (XQ-AS52)",
 	"Sony Xperia L",
+	"Sony Xperia 1 III",
+	"Sony ZV-1 (DCZV1/B)",
+	"Sony ZV-E10",
 	"STV680 VGA",
 	"PtGrey GRAS-50S5C",
 	"JaiPulnix BB-500CL",
 	"JaiPulnix BB-500GE",
 	"SVS SVS625CL",
+	"Vivo X51 5G (V2006)",
 	"Yi M1",
 	"YUNEEC CGO3",
 	"YUNEEC CGO3P",
 	"YUNEEC CGO4",
 	"Xiaomi MI3",
+	"Xiaomi MI 8",
 	"Xiaomi MI 9 Lite",
+	"Xiaomi MI MAX",
+	"Xiaomi POCO M3",
 	"Xiaomi RedMi Note3 Pro",
 	"Xiaomi RedMi Note7",
+	"Xiaomi RedMi Note 8T",
 	"Xiaomi FIMI X8SE",
 	"Xiaoyi YIAC3 (YI 4k)",
+	"Zeiss ZX1",
 	"Zenit M",
 	NULL
 };
